@@ -2,7 +2,7 @@
 from .hook import HOOKS, Hook
 
 
-@HOOKS.register_module
+@HOOKS.register_module()
 class ClosureHook(Hook):
 
     def __init__(self, fn_name, fn):
